
-- MORECOLORS curse: raises the number of colors from 6 to --------------------

ID_CURSE_MORECOLORS=9

function morecolors_do_curse(sent)
    if sent==0 then
        u61_send_curse(ID_CURSE_MORECOLORS)
    else
        u61_register_curse(ID_CURSE_MORECOLORS,30000,0)
    end
end

function morecolors_get_nb()
    local nb_colors

    if u61_get_curse_age(ID_CURSE_MORECOLORS)>=0 then
        nb_colors=7
    else
        nb_colors=6
    end        

    return nb_colors
end